@@ -1,5 +1,5 @@
 /* server.c --- SASL mechanism GSSAPI as defined in RFC 2222, server side.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,7 +20,7 @@
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -33,7 +33,7 @@
 /* Get specification. */
 #include "x-gssapi.h"
 
-#ifdef USE_GSS
+#ifdef HAVE_LIBGSS
 # include <gss.h>
 #elif HAVE_GSSAPI_H		/* Heimdal GSSAPI */
 # include <gssapi.h>
@@ -236,7 +236,8 @@ _gsasl_gssapi_server_step (Gsasl_session * sctx,
 	}
 
       gsasl_property_set_raw (sctx, GSASL_AUTHZID,
-			      (char*)bufdesc2.value + 4, bufdesc2.length - 4);
+			      (char *) bufdesc2.value + 4,
+			      bufdesc2.length - 4);
 
       maj_stat = gss_display_name (&min_stat, state->client,
 				   &client_name, &mech_type);
