@@ -1,5 +1,5 @@
 /* gsasl-mech.h --- Header file for mechanism handling in GNU SASL Library.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -59,6 +59,7 @@ struct Gsasl_mechanism
 typedef struct Gsasl_mechanism Gsasl_mechanism;
 
 /* Register new mechanism: register.c. */
-extern int gsasl_register (Gsasl * ctx, const Gsasl_mechanism * mech);
+extern GSASL_API int gsasl_register (Gsasl * ctx,
+				     const Gsasl_mechanism * mech);
 
 #endif /* GSASL_MECH_H */
