@@ -1,5 +1,5 @@
 /* gsasl.h --- Header file for GNU SASL Library.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -27,18 +27,19 @@
 # include <stddef.h>		/* size_t */
 # include <unistd.h>		/* ssize_t */
 
-/* GSASL Windows DLL */
+/* GSASL Windows DLL.  Only needed when this file is used in Visual
+   Studio.  Export and import happens automatically in MinGW. */
 #ifndef GSASL_API
-# if defined(_WIN32) && !defined(GSASL_STATIC)
+# if defined _MSC_VER && !defined GSASL_STATIC
 #  ifdef GSASL_EXPORTS
-#   define GSASL_API  __declspec(dllexport)
-#  else	/* GSASL_EXPORTS */
-#   define GSASL_API  __declspec(dllimport)
-#  endif /* GSASL_EXPORTS */
-# else /* _WIN32 && !GSASL_STATIC */
+#   define GSASL_API __declspec(dllexport)
+#  else
+#   define GSASL_API __declspec(dllimport)
+#  endif
+# else
 #  define GSASL_API
-# endif	/* _WIN32 && !GSASL_STATIC */
-#endif /* GSASL_API */
+# endif
+#endif
 
 # ifdef __cplusplus
 extern "C"
@@ -52,7 +53,7 @@ extern "C"
    * Used together with stringprep_check_version() to verify header file
    * and run-time library consistency.
    */
-# define GSASL_VERSION "0.2.28"
+# define GSASL_VERSION "1.0"
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -152,6 +153,7 @@ extern "C"
     GSASL_SUGGESTED_PIN = 9,
     GSASL_PIN = 10,
     GSASL_REALM = 11,
+    GSASL_DIGEST_MD5_HASHED_PASSWORD = 12,
     /* Server validation callback properties. */
     GSASL_VALIDATE_SIMPLE = 500,
     GSASL_VALIDATE_EXTERNAL = 501,
@@ -246,10 +248,11 @@ extern "C"
   extern GSASL_API int gsasl_decode (Gsasl_session * sctx,
 				     const char *input, size_t input_len,
 				     char **output, size_t * output_len);
-  extern GSASL_API const char *gsasl_mechanism_name (Gsasl_session *sctx);
+  extern GSASL_API const char *gsasl_mechanism_name (Gsasl_session * sctx);
 
   /* Error handling: error.c */
   extern GSASL_API const char *gsasl_strerror (int err);
+  extern GSASL_API const char *gsasl_strerror_name (int err);
 
   /* Internationalized string processing: stringprep.c */
   extern GSASL_API int gsasl_saslprep (const char *in,
