@@ -1,5 +1,5 @@
 /* internal.h --- Internal header with hidden library handle structures.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -104,4 +104,11 @@ struct Gsasl_session
 #endif
 };
 
+#ifndef GSASL_NO_OBSOLETE
+const char *
+_gsasl_obsolete_property_map (Gsasl_session * sctx, Gsasl_property prop);
+int _gsasl_obsolete_callback (Gsasl * ctx, Gsasl_session * sctx,
+			      Gsasl_property prop);
+#endif
+
 #endif /* INTERNAL_H */
