@@ -1,5 +1,5 @@
 /* property.c --- Callback property handling.
- * Copyright (C) 2004  Simon Josefsson
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -13,9 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * License along with GNU SASL Library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License License along with GNU SASL Library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -71,6 +72,13 @@ map (Gsasl_session * sctx, Gsasl_property prop)
       p = &sctx->gssapi_display_name;
       break;
 
+    case GSASL_REALM:
+      p = &sctx->realm;
+      break;
+
+    case GSASL_DIGEST_MD5_HASHED_PASSWORD:
+      p = &sctx->digest_md5_hashed_password;
+
     default:
       break;
     }
@@ -121,7 +129,7 @@ gsasl_property_set (Gsasl_session * sctx, Gsasl_property prop,
  **/
 void
 gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
-		     const char *data, size_t len)
+			const char *data, size_t len)
 {
   char **p = map (sctx, prop);
 
@@ -132,8 +140,11 @@ gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
       if (data)
 	{
 	  *p = malloc (len + 1);
-	  memcpy (*p, data, len);
-	  (*p)[len] = '\0';
+	  if (*p)
+	    {
+	      memcpy (*p, data, len);
+	      (*p)[len] = '\0';
+	    }
 	}
       else
 	*p = NULL;
@@ -192,7 +203,7 @@ gsasl_property_fast (Gsasl_session * sctx, Gsasl_property prop)
  * the corresponding property.  This behaviour of this function will
  * be removed when the obsolete callback interfaces are removed.
  *
- * Return value: Return data for property, or NULL if no value known.
+ * Return value: Return data for property, or %NULL if no value known.
  *
  * Since: 0.2.0
  **/
@@ -209,118 +220,7 @@ gsasl_property_get (Gsasl_session * sctx, Gsasl_property prop)
 
 #ifndef GSASL_NO_OBSOLETE
   if (!p)
-    {
-      Gsasl_client_callback_anonymous cb_anonymous;
-      Gsasl_client_callback_authorization_id cb_authorization_id;
-      Gsasl_client_callback_authentication_id cb_authentication_id;
-      Gsasl_client_callback_password cb_password;
-      Gsasl_client_callback_passcode cb_passcode;
-      Gsasl_client_callback_pin cb_pin;
-      Gsasl_client_callback_service cb_service;
-      char buf[BUFSIZ];
-      size_t buflen = BUFSIZ - 1;
-      int res;
-
-      /* Call obsolete callbacks to get properties.  Remove this when
-       * the obsolete callbacks are no longer supported. */
-
-      switch (prop)
-	{
-	case GSASL_SERVICE:
-	  cb_service = gsasl_client_callback_service_get (sctx->ctx);
-	  if (!cb_service)
-	    break;
-	  res = cb_service (sctx, buf, &buflen, NULL, 0, NULL, 0);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_HOSTNAME:
-	  cb_service = gsasl_client_callback_service_get (sctx->ctx);
-	  if (!cb_service)
-	    break;
-	  res = cb_service (sctx, NULL, 0, buf, &buflen, NULL, 0);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_ANONYMOUS_TOKEN:
-	  cb_anonymous = gsasl_client_callback_anonymous_get (sctx->ctx);
-	  if (!cb_anonymous)
-	    break;
-	  res = cb_anonymous (sctx, buf, &buflen);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_AUTHID:
-	  cb_authentication_id =
-	    gsasl_client_callback_authentication_id_get (sctx->ctx);
-	  if (!cb_authentication_id)
-	    break;
-	  res = cb_authentication_id (sctx, buf, &buflen);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_AUTHZID:
-	  cb_authorization_id =
-	    gsasl_client_callback_authorization_id_get (sctx->ctx);
-	  if (!cb_authorization_id)
-	    break;
-	  res = cb_authorization_id (sctx, buf, &buflen);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_PASSWORD:
-	  cb_password = gsasl_client_callback_password_get (sctx->ctx);
-	  if (!cb_password)
-	    break;
-	  res = cb_password (sctx, buf, &buflen);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_PASSCODE:
-	  cb_passcode = gsasl_client_callback_passcode_get (sctx->ctx);
-	  if (!cb_passcode)
-	    break;
-	  res = cb_passcode (sctx, buf, &buflen);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	case GSASL_PIN:
-	  cb_pin = gsasl_client_callback_pin_get (sctx->ctx);
-	  if (!cb_pin)
-	    break;
-	  res = cb_pin (sctx, sctx->suggestedpin, buf, &buflen);
-	  if (res != GSASL_OK)
-	    break;
-	  buf[buflen] = '\0';
-	  gsasl_property_set (sctx, prop, buf);
-	  break;
-
-	default:
-	  break;
-	}
-      p = gsasl_property_fast (sctx, prop);
-    }
+    p = _gsasl_obsolete_property_map (sctx, prop);
 #endif
 
   return p;
